@@ -1,7 +1,10 @@
 from xarray.backends import BackendEntrypoint
-from pyrregular.io_utils import load_from_file
 from xarray.core.indexing import NdArrayLikeIndexingAdapter
-from pyrregular.accessor import IrregularAccessor  # this is needed to register the accessor
+
+from pyrregular.accessor import (  # this is needed to register the accessor
+    IrregularAccessor,
+)
+from pyrregular.io_utils import load_from_file
 
 
 class IrregularEntrypoint(BackendEntrypoint):
@@ -15,4 +18,3 @@ class IrregularEntrypoint(BackendEntrypoint):
         da.data = NdArrayLikeIndexingAdapter(da.data)
         da.name = "data"
         return da.to_dataset()
-
