@@ -1,8 +1,9 @@
 import numpy as np
 from sklearn.base import BaseEstimator, ClassifierMixin
-from pyrregular.conversion_utils import to_pypots
 from sklearn.model_selection import train_test_split
 
+from pyrregular.conversion_utils import to_pypots
+
 
 class PyPOTSWrapper(BaseEstimator, ClassifierMixin):
     def __init__(self, model, model_params, random_state=None):
@@ -34,7 +35,11 @@ class PyPOTSWrapper(BaseEstimator, ClassifierMixin):
 
     def _split(self, X, y):
         try:
-            X_train, X_val, y_train, y_val = train_test_split(X, y, stratify=y, random_state=self.random_state)
+            X_train, X_val, y_train, y_val = train_test_split(
+                X, y, stratify=y, random_state=self.random_state
+            )
         except ValueError:
-            X_train, X_val, y_train, y_val = train_test_split(X, y, random_state=self.random_state)
+            X_train, X_val, y_train, y_val = train_test_split(
+                X, y, random_state=self.random_state
+            )
         return to_pypots(X_train, y_train), to_pypots(X_val, y_val)
